{===============================================================================
  CSDecodeTextInspector Unit

  CodeSite - Viewer Plug-In Unit


  Components/Classes
  ------------------------------------------------------------------------------
  TCSDecodeTextInspector
    Class that implements the Decode Text Inspector.


  Modification History
  ------------------------------------------------------------------------------
  5.0    (04 Jan 2024)
    * Initial Release.


  Copyright  1998-2024 by Raize Software, Inc. All Rights Reserved.
===============================================================================}

unit CSDecodeTextInspector;

interface

uses
  System.Classes,
  Vcl.Controls,
  CodeSiteCustomPlugIns;

type
  TCSDecodeTextInspector = class( TCodeSiteCustomInspector )
  public
    function CreateInspectorControl: TWinControl; override;

    function GetMessageType: Integer; override;
    function GetName: string; override;
    function GetDescription: string; override;
    function GetVersion: string; override;
    function GetEmailAddress: string; override;
    function GetWebSite: string; override;
  end;

procedure Register;

implementation

uses
  System.SysUtils,
  Vcl.ClipBrd,
  CSDecodeTextForm;

const
  // Custom messages that will be shared by other CodeSite users, should
  // have an offset greater than 1000, and should be registered with Raize
  // Software to avoid conflicts with other products.
  //
  // Internally used messages should be defined with offsets between 1 and 999.
  csmEncryptedText = csmUser + 1;
  

{====================================}
{== TCSDecodeTextInspector Methods ==}
{====================================}


function TCSDecodeTextInspector.CreateInspectorControl: TWinControl;
begin
  Result := TfrmDecodeText.Create( nil );
end;



function TCSDecodeTextInspector.GetMessageType: Integer;
begin
  Result := csmEncryptedText;
end;


function TCSDecodeTextInspector.GetName: string;
begin
  Result := 'Decode Text Inspector';
end;


function TCSDecodeTextInspector.GetDescription: string;
begin
  Result := 'This inspector decodes a csmEncodedText message that contains base64 ' +
            'encoded data in the message details.';
end;


function TCSDecodeTextInspector.GetVersion: string;
begin
  Result := '5.1';
end;


function TCSDecodeTextInspector.GetEmailAddress: string;
begin
  Result := 'support@raize.com';
end;


function TCSDecodeTextInspector.GetWebSite: string;
begin
  Result := 'www.raize.com';
end;


{========================}
{== Register Procedure ==}
{========================}

procedure Register;
begin
  if Assigned( PlugInManager ) then
  begin
    PlugInManager.RegisterInspector( TCSDecodeTextInspector.Create );
  end;
end;


end.
